@@ -485,15 +485,15 @@ gnc_ui_account_get_tax_info_string (const Account *account)
             return NULL;
         /* tax_related && !code */
         else
-        /* Translators: This and the following strings appear on
-         * the account tab if the Tax Info column is displayed,
-         * i.e. if the user wants to record the tax form number
-         * and location on that tax form which corresponds to this
-         * gnucash account. For the US Income Tax support in
-         * gnucash, each tax code that can be assigned to an
-         * account generally corresponds to a specific line number
-         * on a paper form and each form has a unique
-         * identification (e.g., Form 1040, Schedule A). */
+            /* Translators: This and the following strings appear on
+             * the account tab if the Tax Info column is displayed,
+             * i.e. if the user wants to record the tax form number
+             * and location on that tax form which corresponds to this
+             * gnucash account. For the US Income Tax support in
+             * gnucash, each tax code that can be assigned to an
+             * account generally corresponds to a specific line number
+             * on a paper form and each form has a unique
+             * identification (e.g., Form 1040, Schedule A). */
             return g_strdup (_("Tax-related but has no tax code"));
     }
     else  /* with tax code */
@@ -676,8 +676,8 @@ gnc_ui_account_get_tax_info_sub_acct_string (const Account *account)
          * on a paper form and each form has a unique
          * identification (e.g., Form 1040, Schedule A). */
         return (sub_acct_tax_number == 0) ? g_strdup ("") :
-                g_strdup_printf (_("(Tax-related subaccounts: %d)"),
-                                 sub_acct_tax_number);
+               g_strdup_printf (_("(Tax-related subaccounts: %d)"),
+                                sub_acct_tax_number);
     }
     else
         return g_strdup ("");
@@ -1297,7 +1297,8 @@ PrintAmountInternal(char *buf, gnc_numeric val, const GNCPrintAmountInfo *info)
 
     if (gnc_numeric_check (val))
     {
-        PWARN ("Bad numeric.");
+        PWARN ("Bad numeric: %s.",
+               gnc_numeric_errorCode_to_string(gnc_numeric_check (val)));
         *buf = '\0';
         return 0;
     }
@@ -1335,7 +1336,8 @@ PrintAmountInternal(char *buf, gnc_numeric val, const GNCPrintAmountInfo *info)
         /* Yes, rounding up can cause overflow.  Check for it. */
         if (gnc_numeric_check(val))
         {
-            PWARN("Bad numeric from rounding.");
+            PWARN ("Bad numeric from rounding: %s.",
+                   gnc_numeric_errorCode_to_string(gnc_numeric_check (val)));
             *buf = '\0';
             return 0;
         }
@@ -1346,7 +1348,8 @@ PrintAmountInternal(char *buf, gnc_numeric val, const GNCPrintAmountInfo *info)
     val = gnc_numeric_sub (val, whole, GNC_DENOM_AUTO, GNC_HOW_RND_NEVER);
     if (gnc_numeric_check (val))
     {
-        PWARN ("Problem with remainder.");
+        PWARN ("Problem with remainder: %s.",
+               gnc_numeric_errorCode_to_string(gnc_numeric_check (val)));
         *buf = '\0';
         return 0;
     }
